@@ -20,7 +20,7 @@ enum PathType {
     Folder,
 }
 
-pub fn create_config_or_exit_early(args: Cli) -> Config {
+pub fn create_config_or_exit_early(args: &Cli) -> Config {
     match create_config(args) {
         Ok(c) => c,
         Err(e) => {
@@ -33,7 +33,7 @@ pub fn create_config_or_exit_early(args: Cli) -> Config {
     }
 }
 
-fn create_config(args: Cli) -> Result<Config, Error> {
+fn create_config(args: &Cli) -> Result<Config, Error> {
     let has_data_from_stdin = !stdin().is_terminal();
 
     validate_input(
@@ -42,7 +42,7 @@ fn create_config(args: Cli) -> Result<Config, Error> {
         args.listen_command.is_some(),
     )?;
 
-    let input_type = determine_input_type(&args, has_data_from_stdin)?;
+    let input_type = determine_input_type(args, has_data_from_stdin)?;
     let input = get_input(input_type)?;
     let output = get_output(has_data_from_stdin, args.to_stdout);
     let follow = should_follow(args.follow, args.listen_command.is_some(), &input);
@@ -51,7 +51,7 @@ fn create_config(args: Cli) -> Result<Config, Error> {
         input,
         output,
         follow,
-        tail: args.tail,
+        start_at_end: args.start_at_end,
     };
 
     Ok(config)
