@@ -6,6 +6,7 @@ pub const MISUSE_SHELL_BUILTIN: i32 = 2;
 
 pub trait Highlight {
     fn should_short_circuit(&self, line_info: &LineInfo) -> bool;
+    fn only_apply_to_segments_not_already_highlighted(&self) -> bool;
     fn apply(&self, input: &str) -> String;
 }
 
@@ -18,7 +19,7 @@ pub struct Config {
     pub input: Input,
     pub output: Output,
     pub follow: bool,
-    pub tail: bool,
+    pub start_at_end: bool,
 }
 
 pub struct PathAndLineCount {
